# Generated by ariadne-codegen
# Source: operations.graphql

from pydantic import Field

from .base_model import BaseModel
from .fragments import CreditGrantFragment


class VoidCreditGrant(BaseModel):
    void_credit_grant: "VoidCreditGrantVoidCreditGrant" = Field(alias="voidCreditGrant")


class VoidCreditGrantVoidCreditGrant(CreditGrantFragment):
    pass


VoidCreditGrant.model_rebuild()



# Generated by ariadne-codegen
# Source: operations.graphql

from typing import List

from pydantic import Field

from .base_model import BaseModel
from .fragments import PageInfoFragment, SubscriptionQueryFragment


class GetSubscriptions(BaseModel):
    subscriptions: "GetSubscriptionsSubscriptions"


class GetSubscriptionsSubscriptions(BaseModel):
    edges: List["GetSubscriptionsSubscriptionsEdges"]
    page_info: "GetSubscriptionsSubscriptionsPageInfo" = Field(alias="pageInfo")


class GetSubscriptionsSubscriptionsEdges(BaseModel):
    node: "GetSubscriptionsSubscriptionsEdgesNode"


class GetSubscriptionsSubscriptionsEdgesNode(SubscriptionQueryFragment):
    pass


class GetSubscriptionsSubscriptionsPageInfo(PageInfoFragment):
    pass


GetSubscriptions.model_rebuild()
GetSubscriptionsSubscriptions.model_rebuild()
GetSubscriptionsSubscriptionsEdges.model_rebuild()
